Common types
===========================


Asset
--------------------------------
.. automodule:: pragma_sdk.common.types.asset
   :members:
   :undoc-members:
   :show-inheritance:

PragmaClient
---------------------------------

.. automodule:: pragma_sdk.common.types.client
   :members:
   :undoc-members:
   :show-inheritance:

Currency
-----------------------------------

.. automodule:: pragma_sdk.common.types.currency
   :members:
   :undoc-members:
   :show-inheritance:

Entries
--------------------------------

.. automodule:: pragma_sdk.common.types.entry
   :members:
   :undoc-members:
   :show-inheritance:

Pair
-------------------------------

.. automodule:: pragma_sdk.common.types.pair
   :members:
   :undoc-members:
   :show-inheritance:

Misc
--------------------------------

.. automodule:: pragma_sdk.common.types.types
   :members:
   :undoc-members:
   :show-inheritance:
